@@ -2,7 +2,7 @@
 import json
 import os
 
-from utils.log_utils import LogUtils as log_utils
+from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
