@@ -1,4 +1,4 @@
-from utils.log_utils import LogUtils as log_utils
+from gdo_arch_utils.utils.log_utils import LogUtils as log_utils
 
 logger = log_utils.get_logger()
 
